@@ -4,7 +4,6 @@
 import numpy as np
 
 from pyphi import utils, constants, models
-from pyphi.network import Network
 
 
 def test_apply_cut():
@@ -24,18 +23,6 @@ def test_apply_cut():
     assert np.array_equal(utils.apply_cut(cut, cm), cut_cm)
 
 
-def test_pyphi_index2state():
-    assert utils.pyphi_index2state(7, 8) == (1, 1, 1, 0, 0, 0, 0, 0)
-    assert utils.pyphi_index2state(1, 3) == (1, 0, 0)
-    assert utils.pyphi_index2state(8, 4) == (0, 0, 0, 1)
-
-
-def test_natural_index2state():
-    assert utils.natural_index2state(7, 8) == (0, 0, 0, 0, 0, 1, 1, 1)
-    assert utils.natural_index2state(1, 3) == (0, 0, 1)
-    assert utils.natural_index2state(8, 4) == (1, 0, 0, 0)
-
-
 def test_phi_eq():
     phi = 0.5
     close_enough = phi - constants.EPSILON/2
